/**
 * ____________________________________________________
 * Microsoft product language ID list
 *
 * @file   ms_lang_code_id.hpp
 * @author mkg <me@mustafagilor.com>
 * @date   17.04.2022
 *
 * SPDX-License-Identifier:    MIT
 * ____________________________________________________
 */

#ifndef TDSL_DETAIL_MS_LANG_CODE_ID_HPP
#define TDSL_DETAIL_MS_LANG_CODE_ID_HPP

#include <tdslite/util/tdsl_inttypes.hpp>

namespace tdsl { namespace detail {

    /**
     * The codes represent languages and dialects used in Microsoft products
     * @see https://docs.microsoft.com/en-us/openspecs/windows_protocols/ms-lcid/
     */
    enum class e_ms_lang_code_id : tdsl::uint32_t
    {
        aa_afar                  = 0x1000,
        aa_dj_afar               = 0x1000,
        aa_er_afar               = 0x1000,
        aa_et_afar               = 0x1000,
        af_afrikaans             = 0x0036,
        af_na_afrikaans          = 0x1000,
        af_za_afrikaans          = 0x0436,
        agq_aghem                = 0x1000,
        agq_cm_aghem             = 0x1000,
        ak_akan                  = 0x1000,
        ak_gh_akan               = 0x1000,
        sq_albanian              = 0x001C,
        sq_al_albanian           = 0x041C,
        sq_mk_albanian           = 0x1000,
        gsw_alsatian             = 0x0084,
        gsw_fr_alsatian          = 0x0484,
        gsw_li_alsatian          = 0x1000,
        gsw_ch_alsatian          = 0x1000,
        am_amharic               = 0x005E,
        am_et_amharic            = 0x045E,
        ar_arabic                = 0x0001,
        ar_dz_arabic             = 0x1401,
        ar_bh_arabic             = 0x3C01,
        ar_td_arabic             = 0x1000,
        ar_km_arabic             = 0x1000,
        ar_dj_arabic             = 0x1000,
        ar_eg_arabic             = 0x0c01,
        ar_er_arabic             = 0x1000,
        ar_iq_arabic             = 0x0801,
        ar_il_arabic             = 0x1000,
        ar_jo_arabic             = 0x2C01,
        ar_kw_arabic             = 0x3401,
        ar_lb_arabic             = 0x3001,
        ar_ly_arabic             = 0x1001,
        ar_mr_arabic             = 0x1000,
        ar_ma_arabic             = 0x1801,
        ar_om_arabic             = 0x2001,
        ar_ps_arabic             = 0x1000,
        ar_qa_arabic             = 0x4001,
        ar_sa_arabic             = 0x0401,
        ar_so_arabic             = 0x1000,
        ar_ss_arabic             = 0x1000,
        ar_sd_arabic             = 0x1000,
        ar_sy_arabic             = 0x2801,
        ar_tn_arabic             = 0x1C01,
        ar_ae_arabic             = 0x3801,
        ar_001_arabic            = 0x1000,
        ar_ye_arabic             = 0x2401,
        hy_armenian              = 0x002B,
        hy_am_armenian           = 0x042B,
        as_assamese              = 0x004D,
        as_in_assamese           = 0x044D,
        ast_asturian             = 0x1000,
        ast_es_asturian          = 0x1000,
        asa_asu                  = 0x1000,
        asa_tz_asu               = 0x1000,
        az_cyrl_azerbaijani      = 0x742C,
        az_cyrl_az_azerbaijani   = 0x082C,
        az_azerbaijani           = 0x002C,
        az_latn_azerbaijani      = 0x782C,
        az_latn_az_azerbaijani   = 0x042C,
        ksf_bafia                = 0x1000,
        ksf_cm_bafia             = 0x1000,
        bm_bamanankan            = 0x1000,
        bm_latn_ml_bamanankan    = 0x1000,
        bn_bangla                = 0x0045,
        bn_bd_bangla             = 0x0845,
        bn_in_bangla             = 0x0445,
        bas_basaa                = 0x1000,
        bas_cm_basaa             = 0x1000,
        ba_bashkir               = 0x006D,
        ba_ru_bashkir            = 0x046D,
        eu_basque                = 0x002D,
        eu_es_basque             = 0x042D,
        be_belarusian            = 0x0023,
        be_by_belarusian         = 0x0423,
        bem_bemba                = 0x1000,
        bem_zm_bemba             = 0x1000,
        bez_bena                 = 0x1000,
        bez_tz_bena              = 0x1000,
        byn_blin                 = 0x1000,
        byn_er_blin              = 0x1000,
        brx_bodo                 = 0x1000,
        brx_in_bodo              = 0x1000,
        bs_cyrl_bosnian          = 0x641A,
        bs_cyrl_ba_bosnian       = 0x201A,
        bs_latn_bosnian          = 0x681A,
        bs_bosnian               = 0x781A,
        bs_latn_ba_bosnian       = 0x141A,
        br_breton                = 0x007E,
        br_fr_breton             = 0x047E,
        bg_bulgarian             = 0x0002,
        bg_bg_bulgarian          = 0x0402,
        my_burmese               = 0x0055,
        my_mm_burmese            = 0x0455,
        ca_catalan               = 0x0003,
        ca_ad_catalan            = 0x1000,
        ca_fr_catalan            = 0x1000,
        ca_it_catalan            = 0x1000,
        ca_es_catalan            = 0x0403,
        ceb_cebuano              = 0x1000,
        ceb_latn_cebuan          = 0x1000,
        ceb_latn_ph_cebuan       = 0x1000,
        tzm_arab_ma_central      = 0x045F,
        tzm_latn_ma_central      = 0x1000,
        ku_central               = 0x0092,
        ku_arab_central          = 0x7c92,
        ku_arab_iq_central       = 0x0492,
        ccp_chakma               = 0x1000,
        ccp_cakm_chakma          = 0x1000,
        ccp_cakm_bd_chakma       = 0x1000,
        ccp_cakm_in_chakma       = 0x1000,
        ce_ru_chechen            = 0x1000,
        chr_cherokee             = 0x005C,
        chr_cher_cherokee        = 0x7c5C,
        chr_cher_us_cherokee     = 0x045C,
        cgg_chiga                = 0x1000,
        cgg_ug_chiga             = 0x1000,
        zh_hans_chinese          = 0x0004,
        zh_chinese               = 0x7804,
        zh_cn_chinese            = 0x0804,
        zh_sg_chinese            = 0x1004,
        zh_hant_chinese          = 0x7C04,
        zh_hk_chinese            = 0x0C04,
        zh_mo_chinese            = 0x1404,
        zh_tw_chinese            = 0x0404,
        cu_ru_church             = 0x1000,
        swc_congo                = 0x1000,
        swc_cd_congo             = 0x1000,
        kw_cornish               = 0x1000,
        kw_gb_cornish            = 0x1000,
        co_corsican              = 0x0083,
        co_fr_corsican           = 0x0483,
        hr_croatian              = 0x001A,
        hr_hr_croatian           = 0x041A,
        hr_ba_croatian           = 0x101A,
        cs_czech                 = 0x0005,
        cs_cz_czech              = 0x0405,
        da_danish                = 0x0006,
        da_dk_danish             = 0x0406,
        da_gl_danish             = 0x1000,
        prs_dari                 = 0x008C,
        prs_af_dari              = 0x048C,
        dv_divehi                = 0x0065,
        dv_mv_divehi             = 0x0465,
        dua_duala                = 0x1000,
        dua_cm_duala             = 0x1000,
        nl_dutch                 = 0x0013,
        nl_aw_dutch              = 0x1000,
        nl_be_dutch              = 0x0813,
        nl_bq_dutch              = 0x1000,
        nl_cw_dutch              = 0x1000,
        nl_nl_dutch              = 0x0413,
        nl_sx_dutch              = 0x1000,
        nl_sr_dutch              = 0x1000,
        dz_dzongkha              = 0x1000,
        dz_bt_dzongkha           = 0x0C51,
        ebu_embu                 = 0x1000,
        ebu_ke_embu              = 0x1000,
        en_english               = 0x0009,
        en_as_english            = 0x1000,
        en_ai_english            = 0x1000,
        en_ag_english            = 0x1000,
        en_au_english            = 0x0C09,
        en_at_english            = 0x1000,
        en_bs_english            = 0x1000,
        en_bb_english            = 0x1000,
        en_be_english            = 0x1000,
        en_bz_english            = 0x2809,
        en_bm_english            = 0x1000,
        en_bw_english            = 0x1000,
        en_io_english            = 0x1000,
        en_vg_english            = 0x1000,
        en_bi_english            = 0x1000,
        en_cm_english            = 0x1000,
        en_ca_english            = 0x1009,
        en_029_english           = 0x2409,
        en_ky_english            = 0x1000,
        en_cx_english            = 0x1000,
        en_cc_english            = 0x1000,
        en_ck_english            = 0x1000,
        en_cy_english            = 0x1000,
        en_dk_english            = 0x1000,
        en_dm_english            = 0x1000,
        en_er_english            = 0x1000,
        en_150_english           = 0x1000,
        en_fk_english            = 0x1000,
        en_fi_english            = 0x1000,
        en_fj_english            = 0x1000,
        en_gm_english            = 0x1000,
        en_de_english            = 0x1000,
        en_gh_english            = 0x1000,
        en_gi_english            = 0x1000,
        en_gd_english            = 0x1000,
        en_gu_english            = 0x1000,
        en_gg_english            = 0x1000,
        en_gy_english            = 0x1000,
        en_hk_english            = 0x3C09,
        en_in_english            = 0x4009,
        en_ie_english            = 0x1809,
        en_im_english            = 0x1000,
        en_il_english            = 0x1000,
        en_jm_english            = 0x2009,
        en_je_english            = 0x1000,
        en_ke_english            = 0x1000,
        en_ki_english            = 0x1000,
        en_ls_english            = 0x1000,
        en_lr_english            = 0x1000,
        en_mo_english            = 0x1000,
        en_mg_english            = 0x1000,
        en_mw_english            = 0x1000,
        en_my_english            = 0x4409,
        en_mt_english            = 0x1000,
        en_mh_english            = 0x1000,
        en_mu_english            = 0x1000,
        en_fm_english            = 0x1000,
        en_ms_english            = 0x1000,
        en_na_english            = 0x1000,
        en_nr_english            = 0x1000,
        en_nl_english            = 0x1000,
        en_nz_english            = 0x1409,
        en_ng_english            = 0x1000,
        en_nu_english            = 0x1000,
        en_nf_english            = 0x1000,
        en_mp_english            = 0x1000,
        en_pk_english            = 0x1000,
        en_pw_english            = 0x1000,
        en_pg_english            = 0x1000,
        en_pn_english            = 0x1000,
        en_pr_english            = 0x1000,
        en_ph_english            = 0x3409,
        en_rw_english            = 0x1000,
        en_kn_english            = 0x1000,
        en_lc_english            = 0x1000,
        en_vc_english            = 0x1000,
        en_ws_english            = 0x1000,
        en_sc_english            = 0x1000,
        en_sl_english            = 0x1000,
        en_sg_english            = 0x4809,
        en_sx_english            = 0x1000,
        en_si_english            = 0x1000,
        en_sb_english            = 0x1000,
        en_za_english            = 0x1C09,
        en_ss_english            = 0x1000,
        en_sh_english            = 0x1000,
        en_sd_english            = 0x1000,
        en_sz_english            = 0x1000,
        en_se_english            = 0x1000,
        en_ch_english            = 0x1000,
        en_tz_english            = 0x1000,
        en_tk_english            = 0x1000,
        en_to_english            = 0x1000,
        en_tt_english            = 0x2c09,
        en_tc_english            = 0x1000,
        en_tv_english            = 0x1000,
        en_ug_english            = 0x1000,
        en_ae_english            = 0x4C09,
        en_gb_english            = 0x0809,
        en_us_english            = 0x0409,
        en_um_english            = 0x1000,
        en_vi_english            = 0x1000,
        en_vu_english            = 0x1000,
        en_001_english           = 0x1000,
        en_zm_english            = 0x1000,
        en_zw_english            = 0x3009,
        eo_esperanto             = 0x1000,
        eo_001_esperanto         = 0x1000,
        et_estonian              = 0x0025,
        et_ee_estonian           = 0x0425,
        ee_ewe                   = 0x1000,
        ee_gh_ewe                = 0x1000,
        ee_tg_ewe                = 0x1000,
        ewo_ewondo               = 0x1000,
        ewo_cm_ewondo            = 0x1000,
        fo_faroese               = 0x0038,
        fo_dk_faroese            = 0x1000,
        fo_fo_faroese            = 0x0438,
        fil_filipino             = 0x0064,
        fil_ph_filipino          = 0x0464,
        fi_finnish               = 0x000B,
        fi_fi_finnish            = 0x040B,
        fr_french                = 0x000C,
        fr_dz_french             = 0x1000,
        fr_be_french             = 0x080C,
        fr_bj_french             = 0x1000,
        fr_bf_french             = 0x1000,
        fr_bi_french             = 0x1000,
        fr_cm_french             = 0x2c0C,
        fr_ca_french             = 0x0c0C,
        fr_029_french            = 0x1C0C,
        fr_cf_french             = 0x1000,
        fr_td_french             = 0x1000,
        fr_km_french             = 0x1000,
        fr_cg_french             = 0x1000,
        fr_cd_french             = 0x240C,
        fr_ci_french             = 0x300C,
        fr_dj_french             = 0x1000,
        fr_gq_french             = 0x1000,
        fr_fr_french             = 0x040C,
        fr_gf_french             = 0x1000,
        fr_pf_french             = 0x1000,
        fr_ga_french             = 0x1000,
        fr_gp_french             = 0x1000,
        fr_gn_french             = 0x1000,
        fr_ht_french             = 0x3c0C,
        fr_lu_french             = 0x140C,
        fr_mg_french             = 0x1000,
        fr_ml_french             = 0x340C,
        fr_mq_french             = 0x1000,
        fr_mr_french             = 0x1000,
        fr_mu_french             = 0x1000,
        fr_yt_french             = 0x1000,
        fr_ma_french             = 0x380C,
        fr_nc_french             = 0x1000,
        fr_ne_french             = 0x1000,
        fr_mc_french             = 0x180C,
        fr_re_french             = 0x200C,
        fr_rw_french             = 0x1000,
        fr_bl_french             = 0x1000,
        fr_mf_french             = 0x1000,
        fr_pm_french             = 0x1000,
        fr_sn_french             = 0x280C,
        fr_sc_french             = 0x1000,
        fr_ch_french             = 0x100C,
        fr_sy_french             = 0x1000,
        fr_tg_french             = 0x1000,
        fr_tn_french             = 0x1000,
        fr_vu_french             = 0x1000,
        fr_wf_french             = 0x1000,
        fy_frisian               = 0x0062,
        fy_nl_frisian            = 0x0462,
        fur_friulian             = 0x1000,
        fur_it_friulian          = 0x1000,
        ff_fulah                 = 0x0067,
        ff_latn_fulah            = 0x7C67,
        ff_latn_bf_fulah         = 0x1000,
        ff_cm_fulah              = 0x1000,
        ff_latn_cm_fulah         = 0x1000,
        ff_latn_gm_fulah         = 0x1000,
        ff_latn_gh_fulah         = 0x1000,
        ff_gn_fulah              = 0x1000,
        ff_latn_gn_fulah         = 0x1000,
        ff_latn_gw_fulah         = 0x1000,
        ff_latn_lr_fulah         = 0x1000,
        ff_mr_fulah              = 0x1000,
        ff_latn_mr_fulah         = 0x1000,
        ff_latn_ne_fulah         = 0x1000,
        ff_ng_fulah              = 0x0467,
        ff_latn_ng_fulah         = 0x0467,
        ff_latn_sn_fulah         = 0x0867,
        ff_latn_sl_fulah         = 0x1000,
        gl_galician              = 0x0056,
        gl_es_galician           = 0x0456,
        lg_ganda                 = 0x1000,
        lg_ug_ganda              = 0x1000,
        ka_georgian              = 0x0037,
        ka_ge_georgian           = 0x0437,
        de_german                = 0x0007,
        de_at_german             = 0x0C07,
        de_be_german             = 0x1000,
        de_de_german             = 0x0407,
        de_it_german             = 0x1000,
        de_li_german             = 0x1407,
        de_lu_german             = 0x1007,
        de_ch_german             = 0x0807,
        el_greek                 = 0x0008,
        el_cy_greek              = 0x1000,
        el_gr_greek              = 0x0408,
        kl_greenlandic           = 0x006F,
        kl_gl_greenlandic        = 0x046F,
        gn_guarani               = 0x0074,
        gn_py_guarani            = 0x0474,
        gu_gujarati              = 0x0047,
        gu_in_gujarati           = 0x0447,
        guz_gusii                = 0x1000,
        guz_ke_gusii             = 0x1000,
        ha_hausa                 = 0x0068,
        ha_latn_hausa            = 0x7C68,
        ha_latn_gh_hausa         = 0x1000,
        ha_latn_ne_hausa         = 0x1000,
        ha_latn_ng_hausa         = 0x0468,
        haw_hawaiian             = 0x0075,
        haw_us_hawaiian          = 0x0475,
        he_hebrew                = 0x000D,
        he_il_hebrew             = 0x040D,
        hi_hindi                 = 0x0039,
        hi_in_hindi              = 0x0439,
        hu_hungarian             = 0x000E,
        hu_hu_hungarian          = 0x040E,
        is_icelandic             = 0x000F,
        is_is_icelandic          = 0x040F,
        ig_igbo                  = 0x0070,
        ig_ng_igbo               = 0x0470,
        id_indonesian            = 0x0021,
        id_id_indonesian         = 0x0421,
        ia_interlingua           = 0x1000,
        ia_fr_interlingua        = 0x1000,
        ia_001_interlingua       = 0x1000,
        iu_inuktitut             = 0x005D,
        iu_latn_inuktitut        = 0x7C5D,
        iu_latn_ca_inuktitut     = 0x085D,
        iu_cans_inuktitut        = 0x785D,
        iu_cans_ca_inuktitut     = 0x045d,
        ga_irish                 = 0x003C,
        ga_ie_irish              = 0x083C,
        it_italian               = 0x0010,
        it_it_italian            = 0x0410,
        it_sm_italian            = 0x1000,
        it_ch_italian            = 0x0810,
        it_va_italian            = 0x1000,
        ja_japanese              = 0x0011,
        ja_jp_japanese           = 0x0411,
        jv_javanese              = 0x1000,
        jv_latn_javanese         = 0x1000,
        jv_latn_id_javanese      = 0x1000,
        dyo_jola_fonyi           = 0x1000,
        dyo_sn_jola_fonyi        = 0x1000,
        kea_kabuverdianu         = 0x1000,
        kea_cv_kabuverdianu      = 0x1000,
        kab_kabyle               = 0x1000,
        kab_dz_kabyle            = 0x1000,
        kkj_kako                 = 0x1000,
        kkj_cm_kako              = 0x1000,
        kln_kalenjin             = 0x1000,
        kln_ke_kalenjin          = 0x1000,
        kam_kamba                = 0x1000,
        kam_ke_kamba             = 0x1000,
        kn_kannada               = 0x004B,
        kn_in_kannada            = 0x044B,
        kr_latn_ng_kanuri        = 0x0471,
        ks_kashmiri              = 0x0060,
        ks_arab_kashmiri         = 0x0460,
        ks_arab_in_kashmiri      = 0x1000,
        ks_deva_in_kashmiri      = 0x0860,
        kk_kazakh                = 0x003F,
        kk_kz_kazakh             = 0x043F,
        km_khmer                 = 0x0053,
        km_kh_khmer              = 0x0453,
        quc_kiche                = 0x0086,
        quc_latn_gt_kiche        = 0x0486,
        ki_kikuyu                = 0x1000,
        ki_ke_kikuyu             = 0x1000,
        rw_kinyarwanda           = 0x0087,
        rw_rw_kinyarwanda        = 0x0487,
        sw_kiswahili             = 0x0041,
        sw_ke_kiswahili          = 0x0441,
        sw_tz_kiswahili          = 0x1000,
        sw_ug_kiswahili          = 0x1000,
        kok_konkani              = 0x0057,
        kok_in_konkani           = 0x0457,
        ko_korean                = 0x0012,
        ko_kr_korean             = 0x0412,
        ko_kp_korean             = 0x1000,
        khq_koyra                = 0x1000,
        khq_ml_koyra             = 0x1000,
        ses_koyraboro            = 0x1000,
        ses_ml_koyraboro         = 0x1000,
        nmg_kwasio               = 0x1000,
        nmg_cm_kwasio            = 0x1000,
        ky_kyrgyz                = 0x0040,
        ky_kg_kyrgyz             = 0x0440,
        ku_arab_ir_kurdish       = 0x1000,
        lkt_lakota               = 0x1000,
        lkt_us_lakota            = 0x1000,
        lag_langi                = 0x1000,
        lag_tz_langi             = 0x1000,
        lo_lao                   = 0x0054,
        lo_la_lao                = 0x0454,
        la_va_latin              = 0x0476,
        lv_latvian               = 0x0026,
        lv_lv_latvian            = 0x0426,
        ln_lingala               = 0x1000,
        ln_ao_lingala            = 0x1000,
        ln_cf_lingala            = 0x1000,
        ln_cg_lingala            = 0x1000,
        ln_cd_lingala            = 0x1000,
        lt_lithuanian            = 0x0027,
        lt_lt_lithuanian         = 0x0427,
        nds_low                  = 0x1000,
        nds_de_low               = 0x1000,
        nds_nl_low               = 0x1000,
        dsb_lower                = 0x7C2E,
        dsb_de_lower             = 0x082E,
        lu_luba_katanga          = 0x1000,
        lu_cd_luba_katanga       = 0x1000,
        luo_luo                  = 0x1000,
        luo_ke_luo               = 0x1000,
        lb_luxembourgish         = 0x006E,
        lb_lu_luxembourgish      = 0x046E,
        luy_luyia                = 0x1000,
        luy_ke_luyia             = 0x1000,
        mk_macedonian            = 0x002F,
        mk_mk_macedonian         = 0x042F,
        jmc_machame              = 0x1000,
        jmc_tz_machame           = 0x1000,
        mgh_makhuwa_meetto       = 0x1000,
        mgh_mz_makhuwa_meetto    = 0x1000,
        kde_makonde              = 0x1000,
        kde_tz_makonde           = 0x1000,
        mg_malagasy              = 0x1000,
        mg_mg_malagasy           = 0x1000,
        ms_malay                 = 0x003E,
        ms_bn_malay              = 0x083E,
        ms_my_malay              = 0x043E,
        ml_malayalam             = 0x004C,
        ml_in_malayalam          = 0x044C,
        mt_maltese               = 0x003A,
        mt_mt_maltese            = 0x043A,
        gv_manx                  = 0x1000,
        gv_im_manx               = 0x1000,
        mi_maori                 = 0x0081,
        mi_nz_maori              = 0x0481,
        arn_mapudungun           = 0x007A,
        arn_cl_mapudungun        = 0x047A,
        mr_marathi               = 0x004E,
        mr_in_marathi            = 0x044E,
        mas_masai                = 0x1000,
        mas_ke_masai             = 0x1000,
        mas_tz_masai             = 0x1000,
        mzn_ir_mazanderani       = 0x1000,
        mer_meru                 = 0x1000,
        mer_ke_meru              = 0x1000,
        mgo_meta                 = 0x1000,
        mgo_cm_meta              = 0x1000,
        moh_mohawk               = 0x007C,
        moh_ca_mohawk            = 0x047C,
        mn_mongolian             = 0x0050,
        mn_cyrl_mongolian        = 0x7850,
        mn_mn_mongolian          = 0x0450,
        mn_mong_mongolian        = 0x7C50,
        mn_mong_cn_mongolian     = 0x0850,
        mn_mong_mn_mongolian     = 0x0C50,
        mfe_morisyen             = 0x1000,
        mfe_mu_morisyen          = 0x1000,
        mua_mundang              = 0x1000,
        mua_cm_mundang           = 0x1000,
        nqo_nko                  = 0x1000,
        nqo_gn_nko               = 0x1000,
        naq_nama                 = 0x1000,
        naq_na_nama              = 0x1000,
        ne_nepali                = 0x0061,
        ne_in_nepali             = 0x0861,
        ne_np_nepali             = 0x0461,
        nnh_ngiemboon            = 0x1000,
        nnh_cm_ngiemboon         = 0x1000,
        jgo_ngomba               = 0x1000,
        jgo_cm_ngomba            = 0x1000,
        lrc_iq_northern          = 0x1000,
        lrc_ir_northern          = 0x1000,
        nd_north                 = 0x1000,
        nd_zw_north              = 0x1000,
        no_norwegian             = 0x0014,
        nb_norwegian             = 0x7C14,
        nb_no_norwegian          = 0x0414,
        nn_norwegian             = 0x7814,
        nn_no_norwegian          = 0x0814,
        nb_sj_norwegian          = 0x1000,
        nus_nuer                 = 0x1000,
        nus_sd_nuer              = 0x1000,
        nus_ss_nuer              = 0x1000,
        nyn_nyankole             = 0x1000,
        nyn_ug_nyankole          = 0x1000,
        oc_occitan               = 0x0082,
        oc_fr_occitan            = 0x0482,
        or_odia                  = 0x0048,
        or_in_odia               = 0x0448,
        om_oromo                 = 0x0072,
        om_et_oromo              = 0x0472,
        om_ke_oromo              = 0x1000,
        os_ossetian              = 0x1000,
        os_ge_ossetian           = 0x1000,
        os_ru_ossetian           = 0x1000,
        ps_pashto                = 0x0063,
        ps_af_pashto             = 0x0463,
        ps_pk_pashto             = 0x1000,
        fa_persian               = 0x0029,
        fa_af_persian            = 0x1000,
        fa_ir_persian            = 0x0429,
        pl_polish                = 0x0015,
        pl_pl_polish             = 0x0415,
        pt_portuguese            = 0x0016,
        pt_ao_portuguese         = 0x1000,
        pt_br_portuguese         = 0x0416,
        pt_cv_portuguese         = 0x1000,
        pt_gq_portuguese         = 0x1000,
        pt_gw_portuguese         = 0x1000,
        pt_lu_portuguese         = 0x1000,
        pt_mo_portuguese         = 0x1000,
        pt_mz_portuguese         = 0x1000,
        pt_pt_portuguese         = 0x0816,
        pt_st_portuguese         = 0x1000,
        pt_ch_portuguese         = 0x1000,
        pt_tl_portuguese         = 0x1000,
        prg_001_prussian         = 0x1000,
        qps_ploca_pseudo         = 0x05FE,
        qps_ploc_pseudo          = 0x0501,
        qps_plocm_pseudo         = 0x09FF,
        pa_punjabi               = 0x0046,
        pa_arab_punjabi          = 0x7C46,
        pa_in_punjabi            = 0x0446,
        pa_arab_pk_punjabi       = 0x0846,
        quz_quechua              = 0x006B,
        quz_bo_quechua           = 0x046B,
        quz_ec_quechua           = 0x086B,
        quz_pe_quechua           = 0x0C6B,
        ksh_ripuarian            = 0x1000,
        ksh_de_ripuarian         = 0x1000,
        ro_romanian              = 0x0018,
        ro_md_romanian           = 0x0818,
        ro_ro_romanian           = 0x0418,
        rm_romansh               = 0x0017,
        rm_ch_romansh            = 0x0417,
        rof_rombo                = 0x1000,
        rof_tz_rombo             = 0x1000,
        rn_rundi                 = 0x1000,
        rn_bi_rundi              = 0x1000,
        ru_russian               = 0x0019,
        ru_by_russian            = 0x1000,
        ru_kz_russian            = 0x1000,
        ru_kg_russian            = 0x1000,
        ru_md_russian            = 0x0819,
        ru_ru_russian            = 0x0419,
        ru_ua_russian            = 0x1000,
        rwk_rwa                  = 0x1000,
        rwk_tz_rwa               = 0x1000,
        ssy_saho                 = 0x1000,
        ssy_er_saho              = 0x1000,
        sah_sakha                = 0x0085,
        sah_ru_sakha             = 0x0485,
        saq_samburu              = 0x1000,
        saq_ke_samburu           = 0x1000,
        smn_sami                 = 0x703B,
        smn_fi_sami              = 0x243B,
        smj_sami                 = 0x7C3B,
        smj_no_sami              = 0x103B,
        smj_se_sami              = 0x143B,
        se_sami                  = 0x003B,
        se_fi_sami               = 0x0C3B,
        se_no_sami               = 0x043B,
        se_se_sami               = 0x083B,
        sms_sami                 = 0x743B,
        sms_fi_sami              = 0x203B,
        sma_sami                 = 0x783B,
        sma_no_sami              = 0x183B,
        sma_se_sami              = 0x1C3B,
        sg_sango                 = 0x1000,
        sg_cf_sango              = 0x1000,
        sbp_sangu                = 0x1000,
        sbp_tz_sangu             = 0x1000,
        sa_sanskrit              = 0x004F,
        sa_in_sanskrit           = 0x044F,
        gd_scottish              = 0x0091,
        gd_gb_scottish           = 0x0491,
        seh_sena                 = 0x1000,
        seh_mz_sena              = 0x1000,
        sr_cyrl_serbian          = 0x6C1A,
        sr_cyrl_ba_serbian       = 0x1C1A,
        sr_cyrl_me_serbian       = 0x301A,
        sr_cyrl_rs_serbian       = 0x281A,
        sr_cyrl_cs_serbian       = 0x0C1A,
        sr_latn_serbian          = 0x701A,
        sr_serbian               = 0x7C1A,
        sr_latn_ba_serbian       = 0x181A,
        sr_latn_me_serbian       = 0x2c1A,
        sr_latn_rs_serbian       = 0x241A,
        sr_latn_cs_serbian       = 0x081A,
        nso_sesotho              = 0x006C,
        nso_za_sesotho           = 0x046C,
        tn_setswana              = 0x0032,
        tn_bw_setswana           = 0x0832,
        tn_za_setswana           = 0x0432,
        ksb_shambala             = 0x1000,
        ksb_tz_shambala          = 0x1000,
        sn_shona                 = 0x1000,
        sn_latn_shona            = 0x1000,
        sn_latn_zw_shona         = 0x1000,
        sd_sindhi                = 0x0059,
        sd_arab_sindhi           = 0x7C59,
        sd_arab_pk_sindhi        = 0x0859,
        si_sinhala               = 0x005B,
        si_lk_sinhala            = 0x045B,
        sk_slovak                = 0x001B,
        sk_sk_slovak             = 0x041B,
        sl_slovenian             = 0x0024,
        sl_si_slovenian          = 0x0424,
        xog_soga                 = 0x1000,
        xog_ug_soga              = 0x1000,
        so_somali                = 0x0077,
        so_dj_somali             = 0x1000,
        so_et_somali             = 0x1000,
        so_ke_somali             = 0x1000,
        so_so_somali             = 0x0477,
        st_sotho                 = 0x0030,
        st_za_sotho              = 0x0430,
        nr_south                 = 0x1000,
        nr_za_south              = 0x1000,
        st_ls_southern           = 0x1000,
        es_spanish               = 0x000A,
        es_ar_spanish            = 0x2C0A,
        es_bz_spanish            = 0x1000,
        es_ve_spanish            = 0x200A,
        es_bo_spanish            = 0x400A,
        es_br_spanish            = 0x1000,
        es_cl_spanish            = 0x340A,
        es_co_spanish            = 0x240A,
        es_cr_spanish            = 0x140A,
        es_cu_spanish            = 0x5c0A,
        es_do_spanish            = 0x1c0A,
        es_ec_spanish            = 0x300A,
        es_sv_spanish            = 0x440A,
        es_gq_spanish            = 0x1000,
        es_gt_spanish            = 0x100A,
        es_hn_spanish            = 0x480A,
        es_419_spanish           = 0x580A,
        es_mx_spanish            = 0x080A,
        es_ni_spanish            = 0x4C0A,
        es_pa_spanish            = 0x180A,
        es_py_spanish            = 0x3C0A,
        es_pe_spanish            = 0x280A,
        es_ph_spanish            = 0x1000,
        es_pr_spanish            = 0x500A,
        es_es_tradnl_spanish     = 0x040A,
        es_es_spanish            = 0x0c0A,
        es_us_spanish            = 0x540A,
        es_uy_spanish            = 0x380A,
        zgh_standard             = 0x1000,
        zgh_tfng_ma_standard     = 0x1000,
        zgh_tfng_standard        = 0x1000,
        ss_swati                 = 0x1000,
        ss_za_swati              = 0x1000,
        ss_sz_swati              = 0x1000,
        sv_swedish               = 0x001D,
        sv_ax_swedish            = 0x1000,
        sv_fi_swedish            = 0x081D,
        sv_se_swedish            = 0x041D,
        syr_syriac               = 0x005A,
        syr_sy_syriac            = 0x045A,
        shi_tachelhit            = 0x1000,
        shi_tfng_tachelhit       = 0x1000,
        shi_tfng_ma_tachelhit    = 0x1000,
        shi_latn_tachelhit       = 0x1000,
        shi_latn_ma_tachelhit    = 0x1000,
        dav_taita                = 0x1000,
        dav_ke_taita             = 0x1000,
        tg_tajik                 = 0x0028,
        tg_cyrl_tajik            = 0x7C28,
        tg_cyrl_tj_tajik         = 0x0428,
        tzm_tamazight            = 0x005F,
        tzm_latn_tamazight       = 0x7C5F,
        tzm_latn_dz_tamazight    = 0x085F,
        ta_tamil                 = 0x0049,
        ta_in_tamil              = 0x0449,
        ta_my_tamil              = 0x1000,
        ta_sg_tamil              = 0x1000,
        ta_lk_tamil              = 0x0849,
        twq_tasawaq              = 0x1000,
        twq_ne_tasawaq           = 0x1000,
        tt_tatar                 = 0x0044,
        tt_ru_tatar              = 0x0444,
        te_telugu                = 0x004A,
        te_in_telugu             = 0x044A,
        teo_teso                 = 0x1000,
        teo_ke_teso              = 0x1000,
        teo_ug_teso              = 0x1000,
        th_thai                  = 0x001E,
        th_th_thai               = 0x041E,
        bo_tibetan               = 0x0051,
        bo_in_tibetan            = 0x1000,
        bo_cn_tibetan            = 0x0451,
        tig_tigre                = 0x1000,
        tig_er_tigre             = 0x1000,
        ti_tigrinya              = 0x0073,
        ti_er_tigrinya           = 0x0873,
        ti_et_tigrinya           = 0x0473,
        to_tongan                = 0x1000,
        to_to_tongan             = 0x1000,
        ts_tsonga                = 0x0031,
        ts_za_tsonga             = 0x0431,
        tr_turkish               = 0x001F,
        tr_cy_turkish            = 0x1000,
        tr_tr_turkish            = 0x041F,
        tk_turkmen               = 0x0042,
        tk_tm_turkmen            = 0x0442,
        uk_ukrainian             = 0x0022,
        uk_ua_ukrainian          = 0x0422,
        hsb_upper                = 0x002E,
        hsb_de_upper             = 0x042E,
        ur_urdu                  = 0x0020,
        ur_in_urdu               = 0x0820,
        ur_pk_urdu               = 0x0420,
        ug_uyghur                = 0x0080,
        ug_cn_uyghur             = 0x0480,
        uz_arab_uzbek            = 0x1000,
        uz_arab_af_uzbek         = 0x1000,
        uz_cyrl_uzbek            = 0x7843,
        uz_cyrl_uz_uzbek         = 0x0843,
        uz_uzbek                 = 0x0043,
        uz_latn_uzbek            = 0x7C43,
        uz_latn_uz_uzbek         = 0x0443,
        vai_vai                  = 0x1000,
        vai_vaii_vai             = 0x1000,
        vai_vaii_lr_vai          = 0x1000,
        vai_latn_lr_vai          = 0x1000,
        vai_latn_vai             = 0x1000,
        ca_es_valencia_valencian = 0x0803,
        ve_venda                 = 0x0033,
        ve_za_venda              = 0x0433,
        vi_vietnamese            = 0x002A,
        vi_vn_vietnamese         = 0x042A,
        vo_volapuk               = 0x1000,
        vo_001_volapuk           = 0x1000,
        vun_vunjo                = 0x1000,
        vun_tz_vunjo             = 0x1000,
        wae_walser               = 0x1000,
        wae_ch_walser            = 0x1000,
        cy_welsh                 = 0x0052,
        cy_gb_welsh              = 0x0452,
        wal_wolaytta             = 0x1000,
        wal_et_wolaytta          = 0x1000,
        wo_wolof                 = 0x0088,
        wo_sn_wolof              = 0x0488,
        xh_xhosa                 = 0x0034,
        xh_za_xhosa              = 0x0434,
        yav_yangben              = 0x1000,
        yav_cm_yangben           = 0x1000,
        ii_yi                    = 0x0078,
        ii_cn_yi                 = 0x0478,
        yi_001_yiddish           = 0x043D,
        yo_yoruba                = 0x006A,
        yo_bj_yoruba             = 0x1000,
        yo_ng_yoruba             = 0x046A,
        dje_zarma                = 0x1000,
        dje_ne_zarma             = 0x1000,
        zu_zulu                  = 0x0035,
        zu_za_zulu               = 0x0435,
    };
}} // namespace tdsl::detail

#endif